import { DndContext } from '@dnd-kit/core';
import { Icon } from '@iconify/react/dist/iconify.js';
import { useAtomValue } from 'jotai';
import { FC } from 'react';
import { ScrollArea } from '../../components/ScrollArea';
import {
  CurrentPatternAtom,
  CurrentPatternDuration,
  PulsesInCurrentPatternAtom,
} from '../../context/Patterns';
import styles from './PulseList.module.css';

const PulseList: FC = () => {
  const pattern = useAtomValue(CurrentPatternAtom);
  const pulses = useAtomValue(PulsesInCurrentPatternAtom);
  const duration = useAtomValue(CurrentPatternDuration);

  return (
    <>
      <div className={styles.pulse_tools}>
        <button className="text">
          <Icon icon="material-symbols-light:play-arrow-outline" />
          <span>Test Run</span>
        </button>
        <button className="text">
          <Icon icon="material-symbols-light:add" />
          <span>Add Pulse</span>
        </button>
        <button className="text">
          <Icon icon="material-symbols-light:delete-forever-outline" />
          <span>Delete Selected</span>
        </button>
      </div>
      <div className={styles.pulse_tools}>
        <div className={styles.attribute_unit}>
          <span>{pulses.length ?? 0}</span>
          <label>Key Pulses</label>
        </div>
        <div className={styles.attribute_unit}>
          <label>Total Duration</label>
          <span>{duration.toFixed(2)} s</span>
        </div>
      </div>
      <div className={styles.pulses}>
        <ScrollArea enableY>
          <DndContext>
            <div className={styles.pulse_cards}>
              {pulses.length === 0 && <div className="empty_prompt">No key pulses.</div>}
            </div>
          </DndContext>
        </ScrollArea>
      </div>
    </>
  );
};

export default PulseList;
